**************************** TABLES AND FIGURES CONSTRUCTION FOR *******************************
**************************** Optimal Taxation of Top Labor Incomes: **************************** 
**************************** A Tale of Three Elasticities **************************************

**************************** AUTHORS:************************************************************
***********                  Thomas Piketty, Emmanuel Saez and Stefanie Stantcheva          *****
*************************************************************************************************


**************************** DATE: **************************************************************
***********                  November 14th 2012  *****************************************************
*************************************************************************************************

**************************** DESCRIPTION ********************************************************
***********                  This do file constructs Figure 5 
***********                  INPUT files: data_compensation_pub.dta contains the data on CEO compensation 
***********                               from Fernandes et. al. (2012) - this is NOT public data
***********                               taxes.dta (online from our websites)
***********                  OUTPUT files: ceocomp_ltotalpay.wmf, ceocomp_ltotalpay.eps
***********                                ceocomp_ceocontrols.wmf, ceocomp_ceocontrols.eps
*************************************************************************************************

clear all
set more off
cap log close

cd ...

log using ceocomp.log, replace

use data_compensation_pub, clear
sort country
merge country using taxes
tab _merge
drop if _merge == 2
drop _merge

* South Africa and Belgium's tax rates are inputted directly as they are not in our 18 OECD countries sample.
* Canada needs to be inverted to deduce pure labor income marginal tax rate
replace mtr = 0.4 if country == "South Africa"
replace mtr = 0.74 if country == "Belgium" 
replace mtr = 1-(1-mtr)/(1+.125) if country == "Canada"

* We end up dropping South Africa because it is not an OECD country and it seems like an outlier.
drop if country == "South Africa"

tab country, gen(country_)
tab ff_industry_nr, gen(industry)

gen lsales = log(sales_usd)

local countrycontrols country_2 - country_14
local firmcontrols lsales tobinq_w roa_w leverage_w return_w stdev_return_w industry2 - industry12
local firmcontrols_noind lsales tobinq_w roa_w leverage_w return_w stdev_return_w

gen age_ceo2 = age_ceo^2
gen time_in_role_ceo2 = time_in_role_ceo^2
local ceocontrols  age_ceo age_ceo2 time_in_role_ceo dummy_college

* Compensation variables: 
* salary_ceo equity_incentives_ceo other_pay_ceo non_equity_incentives_ceo (bonus) total_pay_ceo

* Governance variables: try to recode them so increases in them = good governance
* Insider ownership (close): according to Fernandez et al, more is better: more instrinsic reward and more monitoring by block holders?
* Indep ratio = independent directors 
* Is CEO also board chairman? (ceo_chairman)1 = bad recode this
gen ceo_nchairman = . 
replace ceo_nchairman = 0 if ceo_chairman == 1
replace ceo_nchairman = 1 if ceo_chairman == 0
* Board positions at other companies of other board members. More means less governance
* (quoted_board_current_board) recode it as the negative. 
gen multiple_board_positions = -quoted_board_current_board
* Institutional ownership: I think this is the variable own_all (matches the summary stats in paper). more = better

gen ret = log(1-mtr)

gen ltotal = log(total_pay_ceo)
gen lsalary = log(salary)
gen lequitypay = log(equity_incentives_ceo)
gen lother = log(other_pay_ceo)
gen lbonus = log(non_equity_incentives_ceo)

gen usdummy = (country == "United States")

foreach var in `ceocontrols' `firmcontrols_noind' close own_all indep_ratio ceo_nchairman quoted_board_current_board n_board {
egen `var'_mean = mean(`var')
gen `var'_adj = `var' - `var'_mean
}

local firmcontrols_adj lsales_adj tobinq_w_adj roa_w_adj leverage_w_adj return_w_adj stdev_return_w_adj industry2 - industry12
local ceocontrols_adj  age_ceo_adj age_ceo2_adj time_in_role_ceo_adj dummy_college_adj

* Regression avec CEO controls:
quietly reg ltotal `firmcontrols_adj' `ceocontrols_adj' close_adj own_all_adj indep_ratio_adj ceo_nchairman_adj quoted_board_current_board_adj n_board_adj , cluster(country)

# delimit ; 
gen ltotal_adj = ltotal - lsales_adj*_b[lsales_adj] - tobinq_w_adj*_b[tobinq_w_adj] - roa_w_adj*_b[roa_w_adj] - leverage_w_adj*_b[leverage_w_adj] - return_w_adj*_b[return_w_adj]
- stdev_return_w_adj*_b[stdev_return_w_adj] - age_ceo_adj*_b[age_ceo_adj] - age_ceo2_adj*_b[age_ceo2_adj] - time_in_role_ceo_adj*_b[time_in_role_ceo_adj] 
- dummy_college_adj*_b[dummy_college_adj] - close_adj*_b[close_adj] - own_all_adj*_b[own_all_adj] - indep_ratio_adj*_b[indep_ratio_adj]
- ceo_nchairman_adj*_b[ceo_nchairman_adj] - quoted_board_current_board_adj*_b[quoted_board_current_board_adj] - n_board_adj*_b[n_board_adj] ; 

# delimit cr

gen totalpay_adj = exp(ltotal_adj)

collapse mtr ltotal ltotal_adj totalpay_adj, by(country)

gen pos = 3
replace pos = 6 if country == "Canada" | country == "Netherlands"
replace pos = 6 if country == "Norway" | country == "Germany"
replace pos = 9 if country == "Italy" 

twoway (scatter ltotal_adj mtr, msize(medium) mcolor(red) mlabel(country) mlabsize(small) mlabcolor(black) mlabv(pos)) ///
, xtitle(Top Income Marginal Tax Rate, size(medium))  ///
ytitle("CEO pay($ million, log-scale) with controls", size(small)) ylabel(13.8 "1.0" 14.22 "1.5" 14.509 "2.0" 14.73 "2.5" 14.91 "3.0" 15.07 "3.5") ///
title("B. Average CEO compensation with controls",color(black) position(12) size(large) justification(center) ring(20)) ///
ttext(  15 75 "Elasticity= 1.90 (.29)", box size(large) just(left) fcolor(white) margin(medsmall)) graphregion(fcolor(white))

graph export ceocomp_ceocontrols.wmf, replace
graph export ceocomp_ceocontrols.eps, replace
graph save ceocomp_ceocontrols.gph, replace

drop pos
gen pos = 3
replace pos = 1 if country == "United Kingdom"
replace pos = 6 if country == "Norway" | country == "Germany"
replace pos = 9 if country == "Canada"

twoway (scatter ltotal mtr, msize(medium) mcolor(red) mlabel(country) mlabsize(small) mlabcolor(black) mlabv(pos)) ///
, xtitle(Top Income Marginal Tax Rate, size(medium))  ///
ytitle("CEO pay($ million, log-scale)", size(medium)) ylabel(13.8 "1.0" 14.22 "1.5" 14.509 "2.0" 14.73 "2.5" 14.91 "3.0" 15.07 "3.5") ///
title("A. Average CEO compensation",color(black) position(12) size(large) justification(center) ring(20)) ///
ttext( 15 0.7 "Elasticity= 1.97 (.27)", box size(large) just(left) fcolor(white) margin(medsmall)) graphregion(fcolor(white))

graph export ceocomp_ltotalpay.wmf, replace
graph export ceocomp_ltotalpay.eps, replace
graph save ceocomp_ltotalpay.gph, replace

cap log close
